Learn R Programming

scimo (version 0.0.3)

cheese_abundance: Abundance of Fungal Communities in Cheese

Description

Fungal community abundance of 74 ASVs sampled from the surface of three different French cheeses.

Usage

data("cheese_abundance", package = "scimo")

data("cheese_taxonomy", package = "scimo")

Arguments

Format

For cheese_abundance, a tibble with columns:

sample

Sample ID.

cheese

Appellation of the cheese. One of Saint-Nectaire, Livarot or Epoisses.

rind_type

One of Natural or Washed.

other columns

Count of the ASV.

For cheese_taxonomy, a tibble with columns:

asv

Amplicon Sequence Variant (ASV) ID.

lineage

Character corresponding to a standard concatenation of taxonomic clades.

other columns

Clade to which the ASV belongs.

Examples

Run this code
data("cheese_abundance", package = "scimo")
cheese_abundance
data("cheese_taxonomy", package = "scimo")
cheese_taxonomy

Run the code above in your browser using DataLab