powered by
Fungal community abundance of 74 ASVs sampled from the surface of three different French cheeses.
data("cheese_abundance", package = "scimo")data("cheese_taxonomy", package = "scimo")
data("cheese_taxonomy", package = "scimo")
For cheese_abundance, a tibble with columns:
cheese_abundance
Sample ID.
Appellation of the cheese. One of Saint-Nectaire, Livarot or Epoisses.
Saint-Nectaire
Livarot
Epoisses
One of Natural or Washed.
Natural
Washed
Count of the ASV.
For cheese_taxonomy, a tibble with columns:
cheese_taxonomy
Amplicon Sequence Variant (ASV) ID.
Character corresponding to a standard concatenation of taxonomic clades.
Clade to which the ASV belongs.
data("cheese_abundance", package = "scimo") cheese_abundance data("cheese_taxonomy", package = "scimo") cheese_taxonomy
Run the code above in your browser using DataLab